# Changes

This is a record of all past statistika releases and what went into them in reverse
chronological order. We follow [semantic versioning](https://semver.org/) and all
releases are available on [Anaconda.org](https://anaconda.org/OpenSourceEconomics/estimagic).



## 0.0.1 - 2023-08-24
